@@ -146,13 +146,14 @@ class BasePo(object):
         :param timeout:
         :return:
         """
-        for _ in range(int(timeout) * 10):
+        end_time = time.time() + timeout
+        while time.time() < end_time:
             if self.iss_current_page(page=self.__page, url=url):
                 return
             await asyncio.sleep(delay=0.1)
         if url.find("://") == -1:
             url = self.get_url_domain() + url
-        raise RuntimeError(f"无法打开/加载页面<{url}>")
+        raise RuntimeError(f"无法打开/加载页面<{url}>，浏览器当前停留在<{self.__page.url}>")
 
     async def capture_network(
             self,
@@ -278,3 +279,16 @@ class BasePo(object):
         await self.__page.route("**/*", intercept)
 
         return captured
+
+    @staticmethod
+    async def simulation_input_element(locator: Locator, text: str, delay: int = 200) -> None:
+        """
+        模拟逐字符输入（可用于触发 JS 事件）
+        :param locator: 元素定位器对象
+        :param text: 输入的内容
+        :param int delay: 每个字符延迟输入 100ms
+        :return:
+        """
+        if isinstance(text, str) is False:
+            text = str(text)
+        await locator.type(text, delay=delay)
\ No newline at end of file
